@@ -17,7 +17,7 @@ class MinioBackend(BackendBase):
     
     def geturl(self, entrypoint):
         bucket, bucket_name = entrypoint.split('/')
-        return 'http://{}/{}/{}'.format(self.domain, bucket, bucket_name)
+        return 'http://{}/{}_{}'.format(self.domain, bucket, bucket_name)
 
     def put(self, file, bucket, bucket_name, tmp=True):
         try:
@@ -25,8 +25,9 @@ class MinioBackend(BackendBase):
                 _bucket = 'tmp_file_' + bucket
             else:
                 _bucket = bucket
+            b_name = '{}_{}'.format(_bucket, bucket_name)
             print('uploading...')
-            ret, e = self.client.upload_file(file, bucket, bucket_name)
+            ret, e = self.client.upload_file(file, self.default_bucket, b_name)
             if ret:
                 print('upload success.')
                 return True, '{}/{}'.format(_bucket, bucket_name)
@@ -41,8 +42,8 @@ class MinioBackend(BackendBase):
 
     def put_buffer(self, buffer, bucket, bucket_name):
         try:
-            # b_name = '{}_{}'.format(bucket, bucket_name)
-            ret, e = self.client.upload_file_by_buffer(buffer, bucket, bucket_name)
+            b_name = '{}_{}'.format(bucket, bucket_name)
+            ret, e = self.client.upload_file_by_buffer(buffer, self.default_bucket, b_name)
             if ret is not None:
                 return True, '{}/{}'.format(bucket, bucket_name)
             return False, '上传失败'
@@ -57,7 +58,7 @@ class MinioBackend(BackendBase):
             if tries >= 3:
                 return False, '下载出错'
             else:
-                url = 'http://{}/{}/{}'.format(self.domain, bucket, bucket_name)
+                url = 'http://{}/{}/{}'.format(self.domain, self.default_bucket, '{}_{}'.format(bucket, bucket_name))
                 with httpx.stream('GET', url) as response:
                     if response.status_code == 200:
                         with open(download_path, mode='wb') as f:
@@ -73,24 +74,7 @@ class MinioBackend(BackendBase):
                 return self.get(download_path, bucket, bucket_name, tries+1)
 
     async def get_async(self, download_path, bucket, bucket_name):
-        try:
-            url = 'http://{}/{}'.format(self.domain, '{}_{}'.format(bucket, bucket_name))
-            print(url)
-            retry_opts = ExponentialRetry(attempts=3)
-            async with RetryClient(retry_options=retry_opts) as session:
-                async with session.get(url) as response:
-                    if response.status == 200:
-                        with open(download_path, mode='wb') as f:
-                            while True:
-                                chunk = await response.content.read(4096)
-                                if not chunk:
-                                    break
-                                f.write(chunk)
-                    else:
-                        raise ValueError()
-            return True, download_path
-        except Exception as e:
-            return False, str(e)
+        return self.get(download_path, bucket, bucket_name)
 
 
             
