@@ -17,17 +17,23 @@ async def main():
         'default_bucket': 'hamuna-images'
     })
 
-    # ret, e = wysf_client.put('/home/superpigy/文档/hamuna-backend/html/index.html', 'tmp', 'hi.html')
+    ret, e = await wysf_client.put_async('/home/superpigy/文档/hamuna-backend/html/index.html', 'tmp', 'hi.html')
+    print(ret)
+
+    bucket, bucket_name = e.split('/')
+    ret = await wysf_client.get_async('test.html', bucket, bucket_name)
+
+    # minio_client = MinioBackend({
+    #     'key': 'hmcz',
+    #     'secret': 'hmcz1234',
+    #     'domain': 'stream.ai.hamuna.club:9001',
+    #     'default_bucket': 'tmps'
+    # })
+    # ret, e = minio_client.put('/home/superpigy/文档/hamuna-backend/html/index.html', 'tmp', 'hi.html')
     # print(ret)
 
-    minio_client = MinioBackend({
-        'key': 'hmcz',
-        'secret': 'hmcz1234',
-        'domain': 'stream.ai.hamuna.club:9001',
-        'default_bucket': 'tmps'
-    })
-    ret, e = wysf_client.put('/home/superpigy/文档/hamuna-backend/html/index.html', 'tmp', 'hi.html')
-    print(ret)
+    # bucket, bucket_name = e.split('/')
+    # ret = minio_client.get('test.html', bucket, bucket_name)
 
 loop = asyncio.get_event_loop()
 loop.run_until_complete(main())
